@@ -54,17 +54,30 @@
 #'
 #' if (require("logspline")) {
 #'   x <- rnorm(1000)
-#'   describe_posterior(x)
-#'   describe_posterior(x, centrality = "all", dispersion = TRUE, test = "all")
-#'   describe_posterior(x, ci = c(0.80, 0.90))
+#'   describe_posterior(x, verbose = FALSE)
+#'   describe_posterior(x,
+#'     centrality = "all",
+#'     dispersion = TRUE,
+#'     test = "all",
+#'     verbose = FALSE
+#'   )
+#'   describe_posterior(x, ci = c(0.80, 0.90), verbose = FALSE)
 #'
 #'   df <- data.frame(replicate(4, rnorm(100)))
-#'   describe_posterior(df)
-#'   describe_posterior(df, centrality = "all", dispersion = TRUE, test = "all")
-#'   describe_posterior(df, ci = c(0.80, 0.90))
+#'   describe_posterior(df, verbose = FALSE)
+#'   describe_posterior(
+#'     df,
+#'     centrality = "all",
+#'     dispersion = TRUE,
+#'     test = "all",
+#'     verbose = FALSE
+#'   )
+#'   describe_posterior(df, ci = c(0.80, 0.90), verbose = FALSE)
 #'
 #'   df <- data.frame(replicate(4, rnorm(20)))
-#'   head(reshape_iterations(describe_posterior(df, keep_iterations = TRUE)))
+#'   head(reshape_iterations(
+#'     describe_posterior(df, keep_iterations = TRUE, verbose = FALSE)
+#'   ))
 #' }
 #' \dontrun{
 #' # rstanarm models
@@ -80,15 +93,6 @@
 #'   describe_posterior(emtrends(model, ~1, "wt"))
 #' }
 #'
-#' # brms models
-#' # -----------------------------------------------
-#' if (require("brms")) {
-#'   model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
-#'   describe_posterior(model)
-#'   describe_posterior(model, centrality = "all", dispersion = TRUE, test = "all")
-#'   describe_posterior(model, ci = c(0.80, 0.90))
-#' }
-#'
 #' # BayesFactor objects
 #' # -----------------------------------------------
 #' if (require("BayesFactor")) {
@@ -106,9 +110,9 @@ describe_posterior <- function(posteriors, ...) {
 
 #' @export
 describe_posterior.default <- function(posteriors, ...) {
-  stop(insight::format_message(
+  insight::format_error(
     paste0("`describe_posterior()` is not yet implemented for objects of class `", class(posteriors)[1], "`.")
-  ), call. = FALSE)
+  )
 }
 
 
@@ -126,10 +130,14 @@ describe_posterior.default <- function(posteriors, ...) {
                                 BF = 1,
                                 ...) {
   if (is.null(x)) {
-    warning("Could not extract posterior samples.", call. = FALSE)
+    insight::format_warning("Could not extract posterior samples.")
     return(NULL)
   }
 
+  # we need this information from the original object
+  if (all(rope_range == "default")) {
+    rope_range <- rope_range(x, ...)
+  }
 
   if (!is.data.frame(x) && !is.numeric(x)) {
     is_stanmvreg <- inherits(x, "stanmvreg")
@@ -142,9 +150,15 @@ describe_posterior.default <- function(posteriors, ...) {
   }
 
   # Arguments fixes
-  if (!is.null(centrality) && length(centrality) == 1 && (centrality == "none" || centrality == FALSE)) centrality <- NULL
-  if (!is.null(ci) && length(ci) == 1 && (is.na(ci) || ci == FALSE)) ci <- NULL
-  if (!is.null(test) && length(test) == 1 && (test == "none" || test == FALSE)) test <- NULL
+  if (!is.null(centrality) && length(centrality) == 1 && (centrality == "none" || isFALSE(centrality))) {
+    centrality <- NULL
+  }
+  if (!is.null(ci) && length(ci) == 1 && (is.na(ci) || isFALSE(ci))) {
+    ci <- NULL
+  }
+  if (!is.null(test) && length(test) == 1 && (test == "none" || isFALSE(test))) {
+    test <- NULL
+  }
 
 
   # Point-estimates
@@ -156,10 +170,13 @@ describe_posterior.default <- function(posteriors, ...) {
       is_stanmvreg
     )
     if (!"Parameter" %in% names(estimates)) {
-      estimates <- cbind(data.frame("Parameter" = "Posterior"), estimates)
+      estimates <- cbind(
+        data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+        estimates
+      )
     }
   } else {
-    estimates <- data.frame("Parameter" = NA)
+    estimates <- data.frame(Parameter = NA)
   }
 
 
@@ -180,10 +197,13 @@ describe_posterior.default <- function(posteriors, ...) {
     )
 
     if (!"Parameter" %in% names(uncertainty)) {
-      uncertainty <- cbind(data.frame("Parameter" = "Posterior"), uncertainty)
+      uncertainty <- cbind(
+        data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+        uncertainty
+      )
     }
   } else {
-    uncertainty <- data.frame("Parameter" = NA)
+    uncertainty <- data.frame(Parameter = NA)
   }
 
 
@@ -196,18 +216,18 @@ describe_posterior.default <- function(posteriors, ...) {
     }
 
     ## TODO no BF for arm::sim
-    if (inherits(x_df, c("sim", "sim.merMod", "mcmc", "stanfit"))) {
+    if (inherits(x, c("sim", "sim.merMod", "mcmc", "stanfit"))) {
       test <- setdiff(test, "bf")
     }
 
     ## TODO enable once "rope()" works for multi-response models
 
     # no ROPE for multi-response models
-    if (insight::is_multivariate(x_df)) {
+    if (insight::is_multivariate(x)) {
       test <- setdiff(test, c("rope", "p_rope"))
-      warning(insight::format_message(
+      insight::format_warning(
         "Multivariate response models are not yet supported for tests `rope` and `p_rope`."
-      ), call. = FALSE)
+      )
     }
 
     # MAP-based p-value
@@ -218,9 +238,15 @@ describe_posterior.default <- function(posteriors, ...) {
         cleaned_parameters,
         is_stanmvreg
       )
-      if (!is.data.frame(test_pmap)) test_pmap <- data.frame("Parameter" = "Posterior", "p_map" = test_pmap)
+      if (!is.data.frame(test_pmap)) {
+        test_pmap <- data.frame(
+          Parameter = "Posterior",
+          p_map = test_pmap,
+          stringsAsFactors = FALSE
+        )
+      }
     } else {
-      test_pmap <- data.frame("Parameter" = NA)
+      test_pmap <- data.frame(Parameter = NA)
     }
 
 
@@ -232,24 +258,33 @@ describe_posterior.default <- function(posteriors, ...) {
         cleaned_parameters,
         is_stanmvreg
       )
-      if (!is.data.frame(test_pd)) test_pd <- data.frame("Parameter" = "Posterior", "pd" = test_pd)
+      if (!is.data.frame(test_pd)) {
+        test_pd <- data.frame(
+          Parameter = "Posterior",
+          pd = test_pd,
+          stringsAsFactors = FALSE
+        )
+      }
     } else {
-      test_pd <- data.frame("Parameter" = NA)
+      test_pd <- data.frame(Parameter = NA)
     }
 
     # Probability of rope
 
-    if (any(c("p_rope") %in% test)) {
+    if ("p_rope" %in% test) {
       test_prope <- .prepare_output(
         p_rope(x_df, range = rope_range, ...),
         cleaned_parameters,
         is_stanmvreg
       )
       if (!"Parameter" %in% names(test_prope)) {
-        test_prope <- cbind(data.frame("Parameter" = "Posterior"), test_prope)
+        test_prope <- cbind(
+          data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+          test_prope
+        )
       }
     } else {
-      test_prope <- data.frame("Parameter" = NA)
+      test_prope <- data.frame(Parameter = NA)
     }
 
     # Probability of significance
@@ -260,44 +295,48 @@ describe_posterior.default <- function(posteriors, ...) {
         cleaned_parameters,
         is_stanmvreg
       )
-      if (!is.data.frame(test_psig)) test_psig <- data.frame("Parameter" = "Posterior", "ps" = test_psig)
+      if (!is.data.frame(test_psig)) {
+        test_psig <- data.frame(
+          Parameter = "Posterior",
+          ps = test_psig,
+          stringsAsFactors = FALSE
+        )
+      }
     } else {
-      test_psig <- data.frame("Parameter" = NA)
+      test_psig <- data.frame(Parameter = NA)
     }
 
 
     # ROPE
 
-    if (any(c("rope") %in% test)) {
+    if ("rope" %in% test) {
       test_rope <- .prepare_output(
         rope(x_df, range = rope_range, ci = rope_ci, ...),
         cleaned_parameters,
         is_stanmvreg
       )
       if (!"Parameter" %in% names(test_rope)) {
-        test_rope <- cbind(data.frame("Parameter" = "Posterior"), test_rope)
+        test_rope <- cbind(
+          data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+          test_rope
+        )
       }
       names(test_rope)[names(test_rope) == "CI"] <- "ROPE_CI"
     } else {
-      test_rope <- data.frame("Parameter" = NA)
+      test_rope <- data.frame(Parameter = NA)
     }
 
 
     # Equivalence test
 
     if (any(c("equivalence", "equivalence_test", "equitest") %in% test)) {
-      if (any("rope" %in% test)) {
-        equi_warnings <- FALSE
-      } else {
-        equi_warnings <- TRUE
-      }
-
+      dot_args <- list(...)
+      dot_args$verbose <- !"rope" %in% test
       test_equi <- .prepare_output(
         equivalence_test(x_df,
           range = rope_range,
           ci = rope_ci,
-          verbose = equi_warnings,
-          ...
+          dot_args
         ),
         cleaned_parameters,
         is_stanmvreg
@@ -305,7 +344,10 @@ describe_posterior.default <- function(posteriors, ...) {
       test_equi$Cleaned_Parameter <- NULL
 
       if (!"Parameter" %in% names(test_equi)) {
-        test_equi <- cbind(data.frame("Parameter" = "Posterior"), test_equi)
+        test_equi <- cbind(
+          data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+          test_equi
+        )
       }
       names(test_equi)[names(test_equi) == "CI"] <- "ROPE_CI"
 
@@ -326,7 +368,10 @@ describe_posterior.default <- function(posteriors, ...) {
         error = function(e) data.frame("Parameter" = NA)
       )
       if (!"Parameter" %in% names(test_bf)) {
-        test_bf <- cbind(data.frame("Parameter" = "Posterior"), test_bf)
+        test_bf <- cbind(
+          data.frame(Parameter = "Posterior", stringsAsFactors = FALSE),
+          test_bf
+        )
       }
     } else {
       test_bf <- data.frame("Parameter" = NA)
@@ -444,7 +489,7 @@ describe_posterior.default <- function(posteriors, ...) {
   out <- datawizard::data_remove(out[order(out$.rowid), ], remove_columns, verbose = FALSE)
 
   # Add iterations
-  if (keep_iterations == TRUE) {
+  if (keep_iterations) {
     row_order <- out$Parameter
     iter <- as.data.frame(t(as.data.frame(x_df, ...)))
     names(iter) <- paste0("iter_", seq_len(ncol(iter)))
@@ -554,7 +599,7 @@ describe_posterior.bayesQR <- function(posteriors,
   )
 
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -631,9 +676,9 @@ describe_posterior.effectsize_std_params <- function(posteriors,
                                                      ...) {
   class(posteriors) <- "data.frame"
 
-  no_unique <- sapply(posteriors, function(col) {
+  no_unique <- vapply(posteriors, function(col) {
     length(unique(col)) == 1
-  })
+  }, FUN.VALUE = TRUE)
 
   if (any(no_unique)) {
     no_unique <- which(no_unique)
@@ -699,7 +744,7 @@ describe_posterior.get_predicted <- function(posteriors,
       ...
     )
   } else {
-    stop("No iterations present in the output.", call. = FALSE)
+    insight::format_error("No iterations present in the output.")
   }
 }
 
@@ -751,7 +796,7 @@ describe_posterior.emmGrid <- function(posteriors,
 
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
 
   out
 }
@@ -783,7 +828,11 @@ describe_posterior.stanreg <- function(posteriors,
                                        diagnostic = c("ESS", "Rhat"),
                                        priors = FALSE,
                                        effects = c("fixed", "random", "all"),
-                                       component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                                       component = c(
+                                         "location", "all", "conditional",
+                                         "smooth_terms", "sigma", "distributional",
+                                         "auxiliary"
+                                       ),
                                        parameters = NULL,
                                        BF = 1,
                                        ...) {
@@ -830,7 +879,7 @@ describe_posterior.stanreg <- function(posteriors,
 
   out <- .add_clean_parameters_attribute(out, posteriors)
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -852,7 +901,11 @@ describe_posterior.stanmvreg <- function(posteriors,
                                          diagnostic = c("ESS", "Rhat"),
                                          priors = FALSE,
                                          effects = c("fixed", "random", "all"),
-                                         component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                                         component = c(
+                                           "location", "all", "conditional",
+                                           "smooth_terms", "sigma", "distributional",
+                                           "auxiliary"
+                                         ),
                                          parameters = NULL,
                                          ...) {
   effects <- match.arg(effects)
@@ -895,7 +948,7 @@ describe_posterior.stanmvreg <- function(posteriors,
 
   out <- .add_clean_parameters_attribute(out, posteriors)
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -969,7 +1022,11 @@ describe_posterior.brmsfit <- function(posteriors,
                                        bf_prior = NULL,
                                        diagnostic = c("ESS", "Rhat"),
                                        effects = c("fixed", "random", "all"),
-                                       component = c("conditional", "zi", "zero_inflated", "all", "location", "distributional", "auxiliary"),
+                                       component = c(
+                                         "conditional", "zi", "zero_inflated",
+                                         "all", "location", "distributional",
+                                         "auxiliary"
+                                       ),
                                        parameters = NULL,
                                        BF = 1,
                                        priors = FALSE,
@@ -1019,7 +1076,7 @@ describe_posterior.brmsfit <- function(posteriors,
 
   out <- .add_clean_parameters_attribute(out, posteriors)
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -1105,7 +1162,7 @@ describe_posterior.bcplm <- function(posteriors,
   }
 
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -1141,7 +1198,7 @@ describe_posterior.bamlss <- function(posteriors,
   )
 
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
@@ -1226,7 +1283,7 @@ describe_posterior.BFBayesFactor <- function(posteriors,
   }
 
   attr(out, "ci_method") <- ci_method
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posteriors))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posteriors))
   class(out) <- c("describe_posterior", "see_describe_posterior", class(out))
   out
 }
