@@ -240,20 +240,6 @@ sexit <- function(x, significant = "default", large = "default", ci = 0.95, ...)
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #' @keywords internal
 .sexit_preprocess <- function(x, significant = "default", large = "default", ...) {
   thresholds <- sexit_thresholds(x)
@@ -262,8 +248,8 @@ sexit <- function(x, significant = "default", large = "default", ci = 0.95, ...)
 
 
 
-  suppressWarnings(resp <- tryCatch(insight::get_response(x), error = function(e) NULL))
-  suppressWarnings(info <- tryCatch(insight::model_info(x), error = function(e) NULL))
+  suppressWarnings(resp <- .safe(insight::get_response(x, type = "mf")))
+  suppressWarnings(info <- .safe(insight::model_info(x, verbose = FALSE)))
   if (!is.null(resp) && !is.null(info) && info$is_linear) {
     sd1 <- significant / stats::sd(resp, na.rm = TRUE)
     sd2 <- large / stats::sd(resp, na.rm = TRUE)
