@@ -1,7 +1,10 @@
 #' @title Find Effect Size Thresholds
 #'
-#' @description This function attempts at automatically finding suitable default values for a "significant" (i.e., non-negligible) and "large" effect. This is to be used with care, and the chosen threshold should always be explicitly reported and justified. See the detail section in [`sexit()`][sexit] for more information.
-#'
+#' @description This function attempts at automatically finding suitable default
+#' values for a "significant" (i.e., non-negligible) and "large" effect. This is
+#' to be used with care, and the chosen threshold should always be explicitly
+#' reported and justified. See the detail section in [`sexit()`][sexit] for more
+#' information.
 #'
 #' @inheritParams rope
 #'
@@ -41,14 +44,14 @@ sexit_thresholds <- function(x, ...) {
 
 
 #' @export
-sexit_thresholds.brmsfit <- function(x, ...) {
-  response <- insight::get_response(x)
-  information <- insight::model_info(x)
+sexit_thresholds.brmsfit <- function(x, verbose = TRUE, ...) {
+  response <- insight::get_response(x, source = "mf")
+  information <- insight::model_info(x, verbose = FALSE)
 
   if (insight::is_multivariate(x)) {
-    mapply(function(i, j) .sexit_thresholds(i, j), x, information, response)
+    mapply(function(i, j) .sexit_thresholds(i, j), x, information, response, verbose)
   } else {
-    .sexit_thresholds(x, information, response)
+    .sexit_thresholds(x, information, response, verbose)
   }
 }
 
@@ -57,24 +60,16 @@ sexit_thresholds.brmsfit <- function(x, ...) {
 sexit_thresholds.stanreg <- sexit_thresholds.brmsfit
 
 #' @export
-sexit_thresholds.BFBayesFactor <- function(x, ...) {
+sexit_thresholds.BFBayesFactor <- function(x, verbose = TRUE, ...) {
   fac <- 1
   if (inherits(x@numerator[[1]], "BFlinearModel")) {
-    response <- tryCatch(
-      {
-        insight::get_response(x)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
-
+    response <- .safe(insight::get_response(x, source = "mf"))
     if (!is.null(response)) {
       fac <- stats::sd(response, na.rm = TRUE)
     }
   }
 
-  fac * .sexit_thresholds(x)
+  fac * .sexit_thresholds(x, verbose = verbose)
 }
 
 #' @export
@@ -129,16 +124,16 @@ sexit_thresholds.zeroinfl <- sexit_thresholds.brmsfit
 sexit_thresholds.bayesQR <- sexit_thresholds.brmsfit
 
 #' @export
-sexit_thresholds.default <- function(x, ...) {
-  .sexit_thresholds(x)
+sexit_thresholds.default <- function(x, verbose = TRUE, ...) {
+  .sexit_thresholds(x, verbose = verbose)
 }
 
 #' @export
-sexit_thresholds.mlm <- function(x, ...) {
-  response <- insight::get_response(x)
-  information <- insight::model_info(x)
+sexit_thresholds.mlm <- function(x, verbose = TRUE, ...) {
+  response <- insight::get_response(x, type = "mf")
+  information <- insight::model_info(x, verbose = FALSE)
 
-  lapply(response, function(i) .sexit_thresholds(x, information, i))
+  lapply(response, function(i) .sexit_thresholds(x, information, i, verbose = verbose))
 }
 
 
@@ -147,7 +142,7 @@ sexit_thresholds.mlm <- function(x, ...) {
 # helper ------------------
 
 
-.sexit_thresholds <- function(x, information = NULL, response = NULL) {
+.sexit_thresholds <- function(x, information = NULL, response = NULL, verbose = TRUE) {
   if (is.null(information) && is.null(response)) {
     norm <- 1
   } else {
@@ -172,10 +167,12 @@ sexit_thresholds.mlm <- function(x, ...) {
 
           # T-tests
         } else if (information$is_ttest) {
-          if ("BFBayesFactor" %in% class(x)) {
+          if (inherits(x, "BFBayesFactor")) {
             stats::sd(x@data[, 1])
           } else {
-            warning("Could not estimate good thresholds, using default values.", call. = FALSE)
+            if (verbose) {
+              insight::format_warning("Could not estimate good thresholds, using default values.")
+            }
             1
           }
 
@@ -190,7 +187,9 @@ sexit_thresholds.mlm <- function(x, ...) {
         }
       },
       error = function(e) {
-        warning("Could not estimate good thresholds, using default values.", call. = FALSE)
+        if (verbose) {
+          insight::format_warning("Could not estimate good thresholds, using default values.")
+        }
         1
       }
     )
