@@ -20,7 +20,7 @@
 #' (where it is a main effect) than it does in the model `Y ~ A + B + A:B`
 #' (where it is a simple effect). In many cases centering of predictors (mean
 #' subtracting for continuous variables, and effects coding via `contr.sum` or
-#' orthonormal coding via {[contr.orthonorm()]} for factors) can reduce this
+#' orthonormal coding via [`contr.equalprior_pairs`] for factors) can reduce this
 #' issue. In any case you should be mindful of this issue.
 #' \cr\cr
 #' See [bayesfactor_models()] details for more info on passed models.
@@ -55,7 +55,6 @@
 #'     diagnostic_file = file.path(tempdir(), "df1.csv")
 #'   )
 #'
-#'
 #'   res <- weighted_posteriors(stan_m0, stan_m1)
 #'
 #'   plot(eti(res))
@@ -97,7 +96,7 @@
 #'   BFmods <- bayesfactor_models(m0, m1)
 #'
 #'   wp <- weighted_posteriors(pred_m0, pred_m1,
-#'     prior_odds = BFmods$BF[2]
+#'     prior_odds = as.numeric(BFmods)[2]
 #'   )
 #'
 #'   # look at first 5 prediction intervals
@@ -133,7 +132,7 @@ weighted_posteriors <- function(..., prior_odds = NULL, missing = 0, verbose = T
 #' @rdname weighted_posteriors
 weighted_posteriors.data.frame <- function(..., prior_odds = NULL, missing = 0, verbose = TRUE) {
   Mods <- list(...)
-  mnames <- sapply(match.call(expand.dots = FALSE)$`...`, .safe_deparse)
+  mnames <- sapply(match.call(expand.dots = FALSE)$`...`, insight::safe_deparse)
 
   # find min nrow
   iterations <- min(sapply(Mods, nrow))
@@ -142,10 +141,12 @@ weighted_posteriors.data.frame <- function(..., prior_odds = NULL, missing = 0,
   if (!is.null(prior_odds)) {
     prior_odds <- c(1, prior_odds)
   } else {
-    warning("'prior_odds = NULL'; Using uniform priors odds.\n",
-      "For weighted data frame, 'prior_odds' should be specified as a numeric vector.",
-      call. = FALSE
-    )
+    if (verbose) {
+      insight::format_warning(
+        "'prior_odds = NULL'; Using uniform priors odds.\n",
+        "For weighted data frame, 'prior_odds' should be specified as a numeric vector."
+      )
+    }
     prior_odds <- rep(1, length(Mods))
   }
 
@@ -160,6 +161,7 @@ weighted_posteriors.data.frame <- function(..., prior_odds = NULL, missing = 0,
   return(res)
 }
 
+
 #' @export
 #' @rdname weighted_posteriors
 weighted_posteriors.stanreg <- function(...,
